@@ -67,6 +67,7 @@ logger = logging.getLogger(__name__)
     help="Unused by Raylab policies. Use policy/exploration_config instead.",
     override=True,
 )
+@option("_use_trajectory_view_api", False, override=True)
 class Trainer(RLlibTrainer, metaclass=ABCMeta):
     """Base class for raylab trainers."""
 
@@ -107,7 +108,13 @@ class Trainer(RLlibTrainer, metaclass=ABCMeta):
 
         # Creating all workers (excluding evaluation workers).
         num_workers = config["num_workers"]
-        self.workers = self._make_workers(env_creator, cls, config, num_workers)
+        self.workers = self._make_workers(
+            env_creator=env_creator,
+            validate_env=None,
+            policy_class=cls,
+            config=config,
+            num_workers=num_workers,
+        )
         self.train_exec_impl = self.execution_plan(self.workers, config)
         self.wandb = WandBLogger(config, self._name)
 
