@@ -53,23 +53,8 @@ class MAGE(EnvFunctionsMixin, UniformModelPriorMixin, Loss):
             models = SME([models])
         self.models = models
 
-    @property
-    def initialized(self) -> bool:
-        """Whether or not the loss function has all the necessary components."""
-        return self._env.initialized
-
-    def transition(self, obs: Tensor, action: Tensor) -> Tuple[Tensor, TensorDict]:
-        # pylint:disable=missing-function-docstring
-        model, _ = self.sample_model()
-        dist_params = model(obs, action)
-        next_obs, _ = model.rsample(dist_params)
-        return next_obs, dist_params
-
     def __call__(self, batch: TensorDict) -> Tuple[Tensor, StatDict]:
-        assert self.initialized, (
-            "Environment functions missing. "
-            "Did you set reward, termination, and dynamics functions?"
-        )
+        self.check_env_fns()
 
         obs = batch[SampleBatch.CUR_OBS]
         action = self.policy(obs)
@@ -88,6 +73,13 @@ class MAGE(EnvFunctionsMixin, UniformModelPriorMixin, Loss):
         info.update(dist_params_stats(dist_params, name="model"))
         return loss, info
 
+    def transition(self, obs: Tensor, action: Tensor) -> Tuple[Tensor, TensorDict]:
+        # pylint:disable=missing-function-docstring
+        model, _ = self.sample_model()
+        dist_params = model(obs, action)
+        next_obs, _ = model.rsample(dist_params)
+        return next_obs, dist_params
+
     def temporal_diff_error(
         self,
         obs: Tensor,
